Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch Call _proc0_tss_ldt_init only once, and rename them.



details:   https://anonhg.NetBSD.org/src/rev/3540765ceb80
branches:  trunk
changeset: 355265:3540765ceb80
user:      maxv <maxv%NetBSD.org@localhost>
date:      Sat Jul 22 09:01:46 2017 +0000

description:
Call _proc0_tss_ldt_init only once, and rename them.

diffstat:

 sys/arch/amd64/amd64/autoconf.c |   6 ++----
 sys/arch/amd64/amd64/machdep.c  |  14 ++++++++------
 sys/arch/i386/i386/machdep.c    |  15 ++++++++-------
 sys/arch/x86/include/cpu.h      |   6 +-----
 4 files changed, 19 insertions(+), 22 deletions(-)

diffs (155 lines):

diff -r 4fe7c5877362 -r 3540765ceb80 sys/arch/amd64/amd64/autoconf.c
--- a/sys/arch/amd64/amd64/autoconf.c   Sat Jul 22 08:59:05 2017 +0000
+++ b/sys/arch/amd64/amd64/autoconf.c   Sat Jul 22 09:01:46 2017 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: autoconf.c,v 1.26 2017/05/23 08:48:34 nonaka Exp $     */
+/*     $NetBSD: autoconf.c,v 1.27 2017/07/22 09:01:46 maxv Exp $       */
 
 /*-
  * Copyright (c) 1990 The Regents of the University of California.
@@ -46,7 +46,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.26 2017/05/23 08:48:34 nonaka Exp $");
+__KERNEL_RCSID(0, "$NetBSD: autoconf.c,v 1.27 2017/07/22 09:01:46 maxv Exp $");
 
 #include "opt_multiprocessor.h"
 #include "opt_intrdebug.h"
@@ -95,8 +95,6 @@
        identify_hypervisor();
 #endif
 
-       x86_64_proc0_tss_ldt_init();
-
        if (config_rootfound("mainbus", NULL) == NULL)
                panic("configure: mainbus not configured");
 
diff -r 4fe7c5877362 -r 3540765ceb80 sys/arch/x86/include/cpu.h
--- a/sys/arch/x86/include/cpu.h        Sat Jul 22 08:59:05 2017 +0000
+++ b/sys/arch/x86/include/cpu.h        Sat Jul 22 09:01:46 2017 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: cpu.h,v 1.74 2017/07/16 14:02:48 cherry Exp $  */
+/*     $NetBSD: cpu.h,v 1.75 2017/07/22 09:01:46 maxv Exp $    */
 
 /*-
  * Copyright (c) 1990 The Regents of the University of California.
@@ -408,10 +408,6 @@
 
 /* machdep.c */
 void   cpu_reset(void);
-void   i386_proc0_tss_ldt_init(void);
-void   cpu_reset(void);
-void   x86_64_proc0_tss_ldt_init(void);
-void   x86_64_init_pcb_tss_ldt(struct cpu_info *);
 
 /* longrun.c */
 u_int  tmx86_get_longrun_mode(void);



Home | Main Index | Thread Index | Old Index
diff -r 4fe7c5877362 -r 3540765ceb80 sys/arch/amd64/amd64/machdep.c
--- a/sys/arch/amd64/amd64/machdep.c    Sat Jul 22 08:59:05 2017 +0000
+++ b/sys/arch/amd64/amd64/machdep.c    Sat Jul 22 09:01:46 2017 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.257 2017/07/22 08:23:19 maxv Exp $       */
+/*     $NetBSD: machdep.c,v 1.258 2017/07/22 09:01:46 maxv Exp $       */
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2000, 2006, 2007, 2008, 2011
@@ -111,7 +111,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.257 2017/07/22 08:23:19 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.258 2017/07/22 09:01:46 maxv Exp $");
 
 /* #define XENDEBUG_LOW  */
 
@@ -299,6 +299,8 @@
 void dodumpsys(void);
 void dumpsys(void);
 
+static void x86_64_proc0_pcb_ldt_init(void);
+
 extern int time_adjusted;      /* XXX no common header */
 
 void dump_misc_init(void);
@@ -394,7 +396,7 @@
 #endif
 
        gdt_init();
-       x86_64_proc0_tss_ldt_init();
+       x86_64_proc0_pcb_ldt_init();
 
        cpu_init_tss(&cpu_info_primary);
 #if !defined(XEN)
@@ -458,10 +460,10 @@
 #endif /* XEN */
 
 /*
  * Set up proc0's TSS and LDT.
  */
-void
-x86_64_proc0_tss_ldt_init(void)
+static void
+x86_64_proc0_pcb_ldt_init(void)
 {
        struct lwp *l = &lwp0;
        struct pcb *pcb = lwp_getpcb(l);
@@ -458,10 +460,10 @@
 
 /*
- * Set up proc0's TSS and LDT.
+ * Set up proc0's PCB and LDT.
  */
diff -r 4fe7c5877362 -r 3540765ceb80 sys/arch/i386/i386/machdep.c
--- a/sys/arch/i386/i386/machdep.c      Sat Jul 22 08:59:05 2017 +0000
+++ b/sys/arch/i386/i386/machdep.c      Sat Jul 22 09:01:46 2017 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: machdep.c,v 1.784 2017/07/22 08:23:18 maxv Exp $       */
+/*     $NetBSD: machdep.c,v 1.785 2017/07/22 09:01:46 maxv Exp $       */
 
 /*-
  * Copyright (c) 1996, 1997, 1998, 2000, 2004, 2006, 2008, 2009
@@ -67,7 +67,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.784 2017/07/22 08:23:18 maxv Exp $");
+__KERNEL_RCSID(0, "$NetBSD: machdep.c,v 1.785 2017/07/22 09:01:46 maxv Exp $");
 
 #include "opt_beep.h"
 #include "opt_compat_ibcs2.h"
@@ -266,7 +266,6 @@
 void (*initclock_func)(void) = i8254_initclocks;
 #endif
 
-
 /*
  * Size of memory segments, before any memory is stolen.
  */
@@ -276,6 +275,8 @@
 void init386(paddr_t);
 void initgdt(union descriptor *);
 
+static void i386_proc0_pcb_ldt_init(void);
+
 extern int time_adjusted;
 
 int *esym;
@@ -481,7 +482,7 @@
 #endif
 
        gdt_init();
-       i386_proc0_tss_ldt_init();
+       i386_proc0_pcb_ldt_init();
 
 #ifndef XEN
        cpu_init_tss(&cpu_info_primary);
@@ -492,10 +493,10 @@
 }
 
 /*
  * Set up proc0's TSS and LDT.
  */
-void
-i386_proc0_tss_ldt_init(void)
+static void
+i386_proc0_pcb_ldt_init(void)
 {
        struct lwp *l = &lwp0;
        struct pcb *pcb = lwp_getpcb(l);
@@ -492,10 +493,10 @@
 
 /*
- * Set up proc0's TSS and LDT.
+ * Set up proc0's PCB and LDT.
  */